@@ -20,7 +20,7 @@
  *
  * adns asynch ON-YES ON-NO ON-DONTKNOW XARGS \
  *             TYPE DOMAIN \
- *             [QUERY-OPTIONS]                               => QUERY-ID
+ *             [QUERY-OPTIONS...]                            => QUERY-ID
  *        calls, later,
  *           [concat ON-YES|ON-NO|ON-DONTKNOW XARGS RESULTS]
  * adns asynch-cancel QUERY-ID
@@ -323,7 +323,7 @@ static void destroy_resolver_defcb(ClientData resolver_v, Tcl_Interp *ip) {
 }
 
 int cht_do_adns_destroy_resolver(ClientData cd, Tcl_Interp *ip, void *res_v) {
-  cht_tabledataid_disposing(ip,res_v,&adnstcl_resolvers);
+  cht_tabledataid_disposing(ip,res_v,&cht_adnstcl_resolvers);
   destroy_resolver(ip,res_v);
   return TCL_OK;
 }
@@ -413,6 +413,7 @@ const AdnsTclRRTypeInfo cht_adnstclrrtypeinfo_entries[]= {
 
   RRTYPE_RAW(ns),
   RRTYPE_RAW(mx),
+  RRTYPE_EXACTLY(txt),
 
   RRTYPE_EXACTLY(soa),
   RRTYPE_EXACTLY(ptr),
@@ -429,7 +430,7 @@ static int oifn_resolver(Tcl_Interp *ip, const OptionInfo *oi,
   void *val_v;
   int rc;
   
-  rc= cht_pat_iddata(ip,arg,&val_v,&adnstcl_resolvers);
+  rc= cht_pat_iddata(ip,arg,&val_v,&cht_adnstcl_resolvers);
   if (rc) return rc;
   op->resolver= val_v;
   return TCL_OK;
@@ -724,7 +725,7 @@ static void asynch_check_now(Resolver *res) {
     query= query_v;
 
     query->aqu= 0;
-    cht_tabledataid_disposing(interp, query, &adnstcl_queries);
+    cht_tabledataid_disposing(interp, query, &cht_adnstcl_queries);
 
     si= (!answer->status ? &query->on_yes
 	 : answer->status > adns_s_max_tempfail ? &query->on_no
@@ -787,7 +788,7 @@ int cht_do_adns_asynch_cancel(ClientData cd, Tcl_Interp *ip, void *query_v) {
 }
 
 static void asynch_query_dispose(Tcl_Interp *interp, Query *query) {
-  cht_tabledataid_disposing(interp, query, &adnstcl_queries);
+  cht_tabledataid_disposing(interp, query, &cht_adnstcl_queries);
   cht_scriptinv_cancel(&query->on_yes);
   cht_scriptinv_cancel(&query->on_no);
   cht_scriptinv_cancel(&query->on_fail);
@@ -800,16 +801,10 @@ static void destroy_query_idtabcb(Tcl_Interp *interp, void *query_v) {
   asynch_query_dispose(interp, query_v);
 }
 
-const IdDataSpec adnstcl_queries= {
+const IdDataSpec cht_adnstcl_queries= {
   "adns", "adns-query-table", destroy_query_idtabcb
 };
 
 /*---------- main hooks for tcl ----------*/
 
-int cht_do_adnstoplevel_adns(ClientData cd, Tcl_Interp *ip,
-		      const Adns_SubCommand *subcmd,
-		      int objc, Tcl_Obj *const *objv) {
-  return subcmd->func(0,ip,objc,objv);
-}
-
 CHT_INIT(adns, {}, CHTI_COMMANDS(cht_adnstoplevel_entries))
