@@ -313,7 +313,7 @@ static int readstorelogrecord(FILE *f, HashTable *ht,
 static int writerecord(FILE *f, const char *key, const HashValue *val) {
   int r;
 
-  r= fprintf(f, "+%d,%d:%s->", strlen(key), val->len, key);
+  r= fprintf(f, "+%zu,%d:%s->", strlen(key), val->len, key);
   if (r<0) return -1;
   
   r= fwrite(val->data, 1, val->len, f);
@@ -935,9 +935,3 @@ int cht_do_cdbwr_lookup_hb(ClientData cd, Tcl_Interp *ip, void *rw_v,
   return cht_cdb_donesomelookup(ip, rw_v, def, result, data, dlen,
 				cht_cdb_storeanswer_hb);
 }
-
-int cht_do_cdbtoplevel_cdb_wr(ClientData cd, Tcl_Interp *ip,
-			      const Cdbwr_SubCommand* subcmd,
-			      int objc, Tcl_Obj *const *objv) {
-  return subcmd->func((void*)subcmd,ip,objc,objv);
-}
