@@ -21,12 +21,6 @@
 
 #include "chiark_tcl_crypto.h"
 
-int cht_do_hbcryptotoplevel_hbcrypto(ClientData cd, Tcl_Interp *ip,
-		       const HBCrypto_SubCommand *subcmd,
-		       int objc, Tcl_Obj *const *objv) {
-  return subcmd->func(0,ip,objc,objv);
-}
-
 CHT_INIT(crypto,
 	 CHTI_OTHER(hbytes)  CHTI_TYPE(cht_blockcipherkey_type),
 	 CHTI_COMMANDS(cht_hbcryptotoplevel_entries))
