@@ -17,5 +17,7 @@
  * 02110-1301, USA.
  */
 
+#include "dgram.h"
 
-  Tcl_RegisterObjType(&sockaddr_type);
+CHT_INIT(dgram, CHTI_TYPE(sockaddr_type),
+	 CHTI_COMMANDS(cht_dgramsockettoplevel_entries))
